Class: Aws::ECRPublic::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ECRPublic::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ecrpublic/client.rb,
sig/client.rbs
Overview
An API client for ECRPublic. To construct a client, you need to configure a :region and :credentials.
client = Aws::ECRPublic::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchCheckLayerAvailabilityResponseSuccess, _BatchDeleteImageResponseSuccess, _CompleteLayerUploadResponseSuccess, _CreateRepositoryResponseSuccess, _DeleteRepositoryPolicyResponseSuccess, _DeleteRepositoryResponseSuccess, _DescribeImageTagsResponseSuccess, _DescribeImagesResponseSuccess, _DescribeRegistriesResponseSuccess, _DescribeRepositoriesResponseSuccess, _GetAuthorizationTokenResponseSuccess, _GetRegistryCatalogDataResponseSuccess, _GetRepositoryCatalogDataResponseSuccess, _GetRepositoryPolicyResponseSuccess, _InitiateLayerUploadResponseSuccess, _ListTagsForResourceResponseSuccess, _PutImageResponseSuccess, _PutRegistryCatalogDataResponseSuccess, _PutRepositoryCatalogDataResponseSuccess, _SetRepositoryPolicyResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UploadLayerPartResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_check_layer_availability(params = {}) ⇒ Types::BatchCheckLayerAvailabilityResponse
Checks the availability of one or more image layers that are within a repository in a public registry.
-
#batch_delete_image(params = {}) ⇒ Types::BatchDeleteImageResponse
Deletes a list of specified images that are within a repository in a public registry.
-
#complete_layer_upload(params = {}) ⇒ Types::CompleteLayerUploadResponse
Informs Amazon ECR that the image layer upload is complete for a specified public registry, repository name, and upload ID.
-
#create_repository(params = {}) ⇒ Types::CreateRepositoryResponse
Creates a repository in a public registry.
-
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryResponse
Deletes a repository in a public registry.
-
#delete_repository_policy(params = {}) ⇒ Types::DeleteRepositoryPolicyResponse
Deletes the repository policy that's associated with the specified repository.
-
#describe_image_tags(params = {}) ⇒ Types::DescribeImageTagsResponse
Returns the image tag details for a repository in a public registry.
-
#describe_images(params = {}) ⇒ Types::DescribeImagesResponse
Returns metadata that's related to the images in a repository in a public registry.
-
#describe_registries(params = {}) ⇒ Types::DescribeRegistriesResponse
Returns details for a public registry.
-
#describe_repositories(params = {}) ⇒ Types::DescribeRepositoriesResponse
Describes repositories that are in a public registry.
-
#get_authorization_token(params = {}) ⇒ Types::GetAuthorizationTokenResponse
Retrieves an authorization token.
-
#get_registry_catalog_data(params = {}) ⇒ Types::GetRegistryCatalogDataResponse
Retrieves catalog metadata for a public registry.
-
#get_repository_catalog_data(params = {}) ⇒ Types::GetRepositoryCatalogDataResponse
Retrieve catalog metadata for a repository in a public registry.
-
#get_repository_policy(params = {}) ⇒ Types::GetRepositoryPolicyResponse
Retrieves the repository policy for the specified repository.
-
#initiate_layer_upload(params = {}) ⇒ Types::InitiateLayerUploadResponse
Notifies Amazon ECR that you intend to upload an image layer.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags for an Amazon ECR Public resource.
-
#put_image(params = {}) ⇒ Types::PutImageResponse
Creates or updates the image manifest and tags that are associated with an image.
-
#put_registry_catalog_data(params = {}) ⇒ Types::PutRegistryCatalogDataResponse
Create or update the catalog data for a public registry.
-
#put_repository_catalog_data(params = {}) ⇒ Types::PutRepositoryCatalogDataResponse
Creates or updates the catalog data for a repository in a public registry.
-
#set_repository_policy(params = {}) ⇒ Types::SetRepositoryPolicyResponse
Applies a repository policy to the specified public repository to control access permissions.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified
resourceArn. -
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
-
#upload_layer_part(params = {}) ⇒ Types::UploadLayerPartResponse
Uploads an image layer part to Amazon ECR.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1710 1711 1712 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1710 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1713 1714 1715 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1713 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_check_layer_availability(params = {}) ⇒ Types::BatchCheckLayerAvailabilityResponse
Checks the availability of one or more image layers that are within a repository in a public registry. When an image is pushed to a repository, each image layer is checked to verify if it has been uploaded before. If it has been uploaded, then the image layer is skipped.
docker CLI to pull, tag, and push images.
88 |
# File 'sig/client.rbs', line 88
def batch_check_layer_availability: (
|
#batch_delete_image(params = {}) ⇒ Types::BatchDeleteImageResponse
Deletes a list of specified images that are within a repository in a
public registry. Images are specified with either an imageTag or
imageDigest.
You can remove a tag from an image by specifying the image's tag in your request. When you remove the last tag from an image, the image is deleted from your repository.
You can completely delete an image (and all of its tags) by specifying the digest of the image in your request.
101 |
# File 'sig/client.rbs', line 101
def batch_delete_image: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1683 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ECRPublic') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ecrpublic' context[:gem_version] = '1.68.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_layer_upload(params = {}) ⇒ Types::CompleteLayerUploadResponse
Informs Amazon ECR that the image layer upload is complete for a
specified public registry, repository name, and upload ID. You can
optionally provide a sha256 digest of the image layer for data
validation purposes.
When an image is pushed, the CompleteLayerUpload API is called once for each new image layer to verify that the upload is complete.
docker CLI to pull, tag, and push images.
121 |
# File 'sig/client.rbs', line 121
def complete_layer_upload: (
|
#create_repository(params = {}) ⇒ Types::CreateRepositoryResponse
Creates a repository in a public registry. For more information, see Amazon ECR repositories in the Amazon Elastic Container Registry User Guide.
135 |
# File 'sig/client.rbs', line 135
def create_repository: (
|
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryResponse
Deletes a repository in a public registry. If the repository contains
images, you must either manually delete all images in the repository
or use the force option. This option deletes all images on your
behalf before deleting the repository.
152 |
# File 'sig/client.rbs', line 152
def delete_repository: (
|
#delete_repository_policy(params = {}) ⇒ Types::DeleteRepositoryPolicyResponse
Deletes the repository policy that's associated with the specified repository.
166 |
# File 'sig/client.rbs', line 166
def delete_repository_policy: (
|
#describe_image_tags(params = {}) ⇒ Types::DescribeImageTagsResponse
Returns the image tag details for a repository in a public registry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
178 |
# File 'sig/client.rbs', line 178
def describe_image_tags: (
|
#describe_images(params = {}) ⇒ Types::DescribeImagesResponse
Returns metadata that's related to the images in a repository in a public registry.
docker images command shows the uncompressed image size. Therefore,
it might return a larger image size than the image sizes that are
returned by DescribeImages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
192 |
# File 'sig/client.rbs', line 192
def describe_images: (
|
#describe_registries(params = {}) ⇒ Types::DescribeRegistriesResponse
Returns details for a public registry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
212 |
# File 'sig/client.rbs', line 212
def describe_registries: (
|
#describe_repositories(params = {}) ⇒ Types::DescribeRepositoriesResponse
Describes repositories that are in a public registry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
224 |
# File 'sig/client.rbs', line 224
def describe_repositories: (
|
#get_authorization_token(params = {}) ⇒ Types::GetAuthorizationTokenResponse
Retrieves an authorization token. An authorization token represents
your IAM authentication credentials. You can use it to access any
Amazon ECR registry that your IAM principal has access to. The
authorization token is valid for 12 hours. This API requires the
ecr-public:GetAuthorizationToken and sts:GetServiceBearerToken
permissions.
237 |
# File 'sig/client.rbs', line 237
def get_authorization_token: (
|
#get_registry_catalog_data(params = {}) ⇒ Types::GetRegistryCatalogDataResponse
Retrieves catalog metadata for a public registry.
246 |
# File 'sig/client.rbs', line 246
def get_registry_catalog_data: (
|
#get_repository_catalog_data(params = {}) ⇒ Types::GetRepositoryCatalogDataResponse
Retrieve catalog metadata for a repository in a public registry. This metadata is displayed publicly in the Amazon ECR Public Gallery.
255 |
# File 'sig/client.rbs', line 255
def get_repository_catalog_data: (
|
#get_repository_policy(params = {}) ⇒ Types::GetRepositoryPolicyResponse
Retrieves the repository policy for the specified repository.
268 |
# File 'sig/client.rbs', line 268
def get_repository_policy: (
|
#initiate_layer_upload(params = {}) ⇒ Types::InitiateLayerUploadResponse
Notifies Amazon ECR that you intend to upload an image layer.
When an image is pushed, the InitiateLayerUpload API is called once for each image layer that hasn't already been uploaded. Whether an image layer uploads is determined by the BatchCheckLayerAvailability API action.
docker CLI to pull, tag, and push images.
280 |
# File 'sig/client.rbs', line 280
def initiate_layer_upload: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags for an Amazon ECR Public resource.
291 |
# File 'sig/client.rbs', line 291
def list_tags_for_resource: (
|
#put_image(params = {}) ⇒ Types::PutImageResponse
Creates or updates the image manifest and tags that are associated with an image.
When an image is pushed and all new image layers have been uploaded, the PutImage API is called once to create or update the image manifest and the tags that are associated with the image.
docker CLI to pull, tag, and push images.
301 |
# File 'sig/client.rbs', line 301
def put_image: (
|
#put_registry_catalog_data(params = {}) ⇒ Types::PutRegistryCatalogDataResponse
Create or update the catalog data for a public registry.
316 |
# File 'sig/client.rbs', line 316
def put_registry_catalog_data: (
|
#put_repository_catalog_data(params = {}) ⇒ Types::PutRepositoryCatalogDataResponse
Creates or updates the catalog data for a repository in a public registry.
326 |
# File 'sig/client.rbs', line 326
def put_repository_catalog_data: (
|
#set_repository_policy(params = {}) ⇒ Types::SetRepositoryPolicyResponse
Applies a repository policy to the specified public repository to control access permissions. For more information, see Amazon ECR Repository Policies in the Amazon Elastic Container Registry User Guide.
340 |
# File 'sig/client.rbs', line 340
def set_repository_policy: (
|
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified
resourceArn. If existing tags on a resource aren't specified in the
request parameters, they aren't changed. When a resource is deleted,
the tags associated with that resource are also deleted.
352 |
# File 'sig/client.rbs', line 352
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
367 |
# File 'sig/client.rbs', line 367
def untag_resource: (
|
#upload_layer_part(params = {}) ⇒ Types::UploadLayerPartResponse
Uploads an image layer part to Amazon ECR.
When an image is pushed, each new image layer is uploaded in parts. The maximum size of each image layer part can be 20971520 bytes (about 20MB). The UploadLayerPart API is called once for each new image layer part.
docker CLI to pull, tag, and push images.
381 |
# File 'sig/client.rbs', line 381
def upload_layer_part: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1703 1704 1705 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1703 def waiter_names [] end |