Class: Aws::ECRPublic::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ECRPublic::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ecrpublic/client.rb
Overview
An API client for ECRPublic. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ECRPublic::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_check_layer_availability(params = {}) ⇒ Types::BatchCheckLayerAvailabilityResponse
Checks the availability of one or more image layers that are within a repository in a public registry.
-
#batch_delete_image(params = {}) ⇒ Types::BatchDeleteImageResponse
Deletes a list of specified images that are within a repository in a public registry.
-
#complete_layer_upload(params = {}) ⇒ Types::CompleteLayerUploadResponse
Informs Amazon ECR that the image layer upload is complete for a specified public registry, repository name, and upload ID.
-
#create_repository(params = {}) ⇒ Types::CreateRepositoryResponse
Creates a repository in a public registry.
-
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryResponse
Deletes a repository in a public registry.
-
#delete_repository_policy(params = {}) ⇒ Types::DeleteRepositoryPolicyResponse
Deletes the repository policy that’s associated with the specified repository.
-
#describe_image_tags(params = {}) ⇒ Types::DescribeImageTagsResponse
Returns the image tag details for a repository in a public registry.
-
#describe_images(params = {}) ⇒ Types::DescribeImagesResponse
Returns metadata that’s related to the images in a repository in a public registry.
-
#describe_registries(params = {}) ⇒ Types::DescribeRegistriesResponse
Returns details for a public registry.
-
#describe_repositories(params = {}) ⇒ Types::DescribeRepositoriesResponse
Describes repositories that are in a public registry.
-
#get_authorization_token(params = {}) ⇒ Types::GetAuthorizationTokenResponse
Retrieves an authorization token.
-
#get_registry_catalog_data(params = {}) ⇒ Types::GetRegistryCatalogDataResponse
Retrieves catalog metadata for a public registry.
-
#get_repository_catalog_data(params = {}) ⇒ Types::GetRepositoryCatalogDataResponse
Retrieve catalog metadata for a repository in a public registry.
-
#get_repository_policy(params = {}) ⇒ Types::GetRepositoryPolicyResponse
Retrieves the repository policy for the specified repository.
-
#initiate_layer_upload(params = {}) ⇒ Types::InitiateLayerUploadResponse
Notifies Amazon ECR that you intend to upload an image layer.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags for an Amazon ECR Public resource.
-
#put_image(params = {}) ⇒ Types::PutImageResponse
Creates or updates the image manifest and tags that are associated with an image.
-
#put_registry_catalog_data(params = {}) ⇒ Types::PutRegistryCatalogDataResponse
Create or update the catalog data for a public registry.
-
#put_repository_catalog_data(params = {}) ⇒ Types::PutRepositoryCatalogDataResponse
Creates or updates the catalog data for a repository in a public registry.
-
#set_repository_policy(params = {}) ⇒ Types::SetRepositoryPolicyResponse
Applies a repository policy to the specified public repository to control access permissions.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified ‘resourceArn`.
-
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
-
#upload_layer_part(params = {}) ⇒ Types::UploadLayerPartResponse
Uploads an image layer part to Amazon ECR.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1712 1713 1714 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1712 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1715 1716 1717 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1715 def errors_module Errors end |
Instance Method Details
#batch_check_layer_availability(params = {}) ⇒ Types::BatchCheckLayerAvailabilityResponse
Checks the availability of one or more image layers that are within a repository in a public registry. When an image is pushed to a repository, each image layer is checked to verify if it has been uploaded before. If it has been uploaded, then the image layer is skipped.
<note markdown=“1”> This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the ‘docker` CLI to pull, tag, and push images.
</note>
539 540 541 542 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 539 def batch_check_layer_availability(params = {}, = {}) req = build_request(:batch_check_layer_availability, params) req.send_request() end |
#batch_delete_image(params = {}) ⇒ Types::BatchDeleteImageResponse
Deletes a list of specified images that are within a repository in a public registry. Images are specified with either an ‘imageTag` or `imageDigest`.
You can remove a tag from an image by specifying the image’s tag in your request. When you remove the last tag from an image, the image is deleted from your repository.
You can completely delete an image (and all of its tags) by specifying the digest of the image in your request.
601 602 603 604 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 601 def batch_delete_image(params = {}, = {}) req = build_request(:batch_delete_image, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1685 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ECRPublic') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ecrpublic' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_layer_upload(params = {}) ⇒ Types::CompleteLayerUploadResponse
Informs Amazon ECR that the image layer upload is complete for a specified public registry, repository name, and upload ID. You can optionally provide a ‘sha256` digest of the image layer for data validation purposes.
When an image is pushed, the CompleteLayerUpload API is called once for each new image layer to verify that the upload is complete.
<note markdown=“1”> This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the ‘docker` CLI to pull, tag, and push images.
</note>
663 664 665 666 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 663 def complete_layer_upload(params = {}, = {}) req = build_request(:complete_layer_upload, params) req.send_request() end |
#create_repository(params = {}) ⇒ Types::CreateRepositoryResponse
Creates a repository in a public registry. For more information, see
- Amazon ECR repositories][1
-
in the *Amazon Elastic Container Registry
User Guide*.
[1]: docs.aws.amazon.com/AmazonECR/latest/userguide/Repositories.html
740 741 742 743 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 740 def create_repository(params = {}, = {}) req = build_request(:create_repository, params) req.send_request() end |
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryResponse
Deletes a repository in a public registry. If the repository contains images, you must either manually delete all images in the repository or use the ‘force` option. This option deletes all images on your behalf before deleting the repository.
787 788 789 790 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 787 def delete_repository(params = {}, = {}) req = build_request(:delete_repository, params) req.send_request() end |
#delete_repository_policy(params = {}) ⇒ Types::DeleteRepositoryPolicyResponse
Deletes the repository policy that’s associated with the specified repository.
827 828 829 830 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 827 def delete_repository_policy(params = {}, = {}) req = build_request(:delete_repository_policy, params) req.send_request() end |
#describe_image_tags(params = {}) ⇒ Types::DescribeImageTagsResponse
Returns the image tag details for a repository in a public registry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
894 895 896 897 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 894 def (params = {}, = {}) req = build_request(:describe_image_tags, params) req.send_request() end |
#describe_images(params = {}) ⇒ Types::DescribeImagesResponse
Returns metadata that’s related to the images in a repository in a public registry.
<note markdown=“1”> Beginning with Docker version 1.9, the Docker client compresses image layers before pushing them to a V2 Docker registry. The output of the ‘docker images` command shows the uncompressed image size. Therefore, it might return a larger image size than the image sizes that are returned by DescribeImages.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
980 981 982 983 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 980 def describe_images(params = {}, = {}) req = build_request(:describe_images, params) req.send_request() end |
#describe_registries(params = {}) ⇒ Types::DescribeRegistriesResponse
Returns details for a public registry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1043 1044 1045 1046 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1043 def describe_registries(params = {}, = {}) req = build_request(:describe_registries, params) req.send_request() end |
#describe_repositories(params = {}) ⇒ Types::DescribeRepositoriesResponse
Describes repositories that are in a public registry.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1116 def describe_repositories(params = {}, = {}) req = build_request(:describe_repositories, params) req.send_request() end |
#get_authorization_token(params = {}) ⇒ Types::GetAuthorizationTokenResponse
Retrieves an authorization token. An authorization token represents your IAM authentication credentials. You can use it to access any Amazon ECR registry that your IAM principal has access to. The authorization token is valid for 12 hours. This API requires the ‘ecr-public:GetAuthorizationToken` and `sts:GetServiceBearerToken` permissions.
1141 1142 1143 1144 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1141 def (params = {}, = {}) req = build_request(:get_authorization_token, params) req.send_request() end |
#get_registry_catalog_data(params = {}) ⇒ Types::GetRegistryCatalogDataResponse
Retrieves catalog metadata for a public registry.
1160 1161 1162 1163 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1160 def get_registry_catalog_data(params = {}, = {}) req = build_request(:get_registry_catalog_data, params) req.send_request() end |
#get_repository_catalog_data(params = {}) ⇒ Types::GetRepositoryCatalogDataResponse
Retrieve catalog metadata for a repository in a public registry. This metadata is displayed publicly in the Amazon ECR Public Gallery.
1203 1204 1205 1206 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1203 def get_repository_catalog_data(params = {}, = {}) req = build_request(:get_repository_catalog_data, params) req.send_request() end |
#get_repository_policy(params = {}) ⇒ Types::GetRepositoryPolicyResponse
Retrieves the repository policy for the specified repository.
1241 1242 1243 1244 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1241 def get_repository_policy(params = {}, = {}) req = build_request(:get_repository_policy, params) req.send_request() end |
#initiate_layer_upload(params = {}) ⇒ Types::InitiateLayerUploadResponse
Notifies Amazon ECR that you intend to upload an image layer.
When an image is pushed, the InitiateLayerUpload API is called once for each image layer that hasn’t already been uploaded. Whether an image layer uploads is determined by the BatchCheckLayerAvailability API action.
<note markdown=“1”> This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the ‘docker` CLI to pull, tag, and push images.
</note>
1288 1289 1290 1291 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1288 def initiate_layer_upload(params = {}, = {}) req = build_request(:initiate_layer_upload, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags for an Amazon ECR Public resource.
1320 1321 1322 1323 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1320 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_image(params = {}) ⇒ Types::PutImageResponse
Creates or updates the image manifest and tags that are associated with an image.
When an image is pushed and all new image layers have been uploaded, the PutImage API is called once to create or update the image manifest and the tags that are associated with the image.
<note markdown=“1”> This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the ‘docker` CLI to pull, tag, and push images.
</note>
1391 1392 1393 1394 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1391 def put_image(params = {}, = {}) req = build_request(:put_image, params) req.send_request() end |
#put_registry_catalog_data(params = {}) ⇒ Types::PutRegistryCatalogDataResponse
Create or update the catalog data for a public registry.
1425 1426 1427 1428 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1425 def put_registry_catalog_data(params = {}, = {}) req = build_request(:put_registry_catalog_data, params) req.send_request() end |
#put_repository_catalog_data(params = {}) ⇒ Types::PutRepositoryCatalogDataResponse
Creates or updates the catalog data for a repository in a public registry.
1480 1481 1482 1483 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1480 def put_repository_catalog_data(params = {}, = {}) req = build_request(:put_repository_catalog_data, params) req.send_request() end |
#set_repository_policy(params = {}) ⇒ Types::SetRepositoryPolicyResponse
Applies a repository policy to the specified public repository to control access permissions. For more information, see [Amazon ECR Repository Policies] in the *Amazon Elastic Container Registry User Guide*.
[1]: docs.aws.amazon.com/AmazonECR/latest/userguide/repository-policies.html
1542 1543 1544 1545 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1542 def set_repository_policy(params = {}, = {}) req = build_request(:set_repository_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified ‘resourceArn`. If existing tags on a resource aren’t specified in the request parameters, they aren’t changed. When a resource is deleted, the tags associated with that resource are also deleted.
1579 1580 1581 1582 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1579 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
1606 1607 1608 1609 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1606 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#upload_layer_part(params = {}) ⇒ Types::UploadLayerPartResponse
Uploads an image layer part to Amazon ECR.
When an image is pushed, each new image layer is uploaded in parts. The maximum size of each image layer part can be 20971520 bytes (about 20MB). The UploadLayerPart API is called once for each new image layer part.
<note markdown=“1”> This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the ‘docker` CLI to pull, tag, and push images.
</note>
1676 1677 1678 1679 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1676 def upload_layer_part(params = {}, = {}) req = build_request(:upload_layer_part, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1705 1706 1707 |
# File 'lib/aws-sdk-ecrpublic/client.rb', line 1705 def waiter_names [] end |